pub async fn spawn_server_with_config(
config: ServerConfig,
) -> Result<ServerHandle, ServerError>Expand description
Spawn a web server with full configuration and perform health check readiness polling.
pub async fn spawn_server_with_config(
config: ServerConfig,
) -> Result<ServerHandle, ServerError>Spawn a web server with full configuration and perform health check readiness polling.