pub struct ServerConfig {
pub mode: ServeMode,
pub port: u16,
pub host: String,
pub health_check_timeout: Duration,
pub health_check_interval: Duration,
}Expand description
Configuration for launching the web server.
Fields
mode: ServeModeServer mode (static folder or external child process).
port: u16Requested port (0 for dynamic port selection).
host: StringHost interface to bind (default: “127.0.0.1”).
health_check_timeout: DurationHealth check timeout.
health_check_interval: DurationHealth check retry interval.
Implementations
Sourceimpl ServerConfig
impl ServerConfig
Sourcepub fn static_dir(root_dir: impl Into<PathBuf>) -> Self
pub fn static_dir(root_dir: impl Into<PathBuf>) -> Self
Create static server config for a root directory on a dynamic port (0).
Sourcepub fn command(cmd: impl Into<String>, args: Vec<String>) -> Self
pub fn command(cmd: impl Into<String>, args: Vec<String>) -> Self
Create command server config for running dx serve or custom CLI.
Sourcepub fn with_cwd(self, cwd: impl Into<PathBuf>) -> Self
pub fn with_cwd(self, cwd: impl Into<PathBuf>) -> Self
Set the working directory for command mode.
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set the health check timeout.